 
/*--------------------------------------------------------------------------+
 | LUX23 - A program for controlling the X-10 UX23A VCR Commander II device |
 | under the Linux operating system.                                        |
 |                                                                          |
 | Lux23 uses Heyu and an X-10 CM17A "Firecracker" RF transmitter to        |
 | configure the UX23A device for sending IR signals to a TV, VCR, DVD,     |
 | CAB, SAT, and/or CD appliance under computer control.                    |
 |                                                                          |
 |              Copyright 2007 Charles W. Sullivan                          |
 |                     All Rights Reserved                                  |
 |                                                                          |
 | This program is free software; you can redistribute it and/or modify     |
 | it under the terms of the GNU General Public License as published by     |
 | the Free Software Foundation; either version 2 of the License, or        |
 | (at your option) any later version.                                      |
 |                                                                          |
 | This program is distributed in the hope that it will be useful,          |
 | but WITHOUT ANY WARRANTY; without even the implied warranty of           |
 | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            |
 | GNU General Public License for more details.                             |
 |                                                                          |
 | You should have received a copy of the GNU General Public License        |
 | along with this program; if not, write to the Free Software Foundation,  |
 | Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.           |
 +--------------------------------------------------------------------------*/

#include <stdio.h>
#include <string.h>
#include <stdlib.h>

#include "lux23.h"

#define PROG_NAME "lux23"
#define VERSION "1.0.0"
#define COPR "Copyright 2007 Charles W. Sullivan"


void init_instruction ( void )
{
   printf(
      "An init signal is being sent every 4 seconds for 1 minute (or until cancelled\n"
      "with <break>).  Press and hold the \"LEARN RM\" (\"PLAY\") button on the UX23A\n"
      "until the LED glows steadily.  Release the button and wait.\n"
      "A single beep from the UX23A indicates success; eight beeps indicates failure.\n"
   );
   return;
}


int main ( int argc, char *argv[] )
{

   char *strlower ( char * );
   void create_luxmask ( void );
   void display_usage ( void );
   int  config_device ( int, char ** );
   int  initialize ( void );
   int  ux_show ( int, char ** );
   int  create_cmdline ( int, char ** );
   int  exec_cmdline ( void );

   int  j;

   if ( argc < 2 ) {
      display_usage();
      return 1;
   }

   for ( j = 1; j < argc; j++ )
      strlower(argv[j]);

   create_luxmask();

   if ( strcmp(argv[1], "config") == 0 ) {
      return config_device(argc, argv);
   }
   else if ( strcmp(argv[1], "init") == 0 ) {
      initialize();
      return 0;
   }
   else if ( strcmp(argv[1], "show") == 0 ) {
      return ux_show(argc, argv);
   }
   else if ( strcmp(argv[1], "version") == 0 ) {
      printf("%s version %s  %s\n", PROG_NAME, VERSION, COPR);
      return 0;
   }
   else {
      if ( create_cmdline(argc, argv) != 0 )
         return 1;
      return exec_cmdline();
   }

   return 0;
}







